%define anolis_release 1

Name:           lv2
Version:        1.18.8
Release:        %{anolis_release}%{?dist}
Summary:        Audio Plugin Standard

# lv2specgen template.html is CC-AT-SA
License:        ISC
URL:            https://lv2plug.in
Source:         https://lv2plug.in/spec/lv2-%{version}.tar.xz

BuildRequires:  asciidoc
Buildrequires:  cairo-devel >= 1.8.10
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  libsndfile-devel
BuildRequires:  meson
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  python3-pygments
Buildrequires:  python3-rdflib
Buildrequires:  python3-markdown
Buildrequires:  python3-lxml

# this package replaces lv2core 
Provides:       lv2core = 6.0
Obsoletes:      lv2core < 6.0
Provides:       lv2-ui = 2.4
Obsoletes:      lv2-ui < 2.4

%description
LV2 is a standard for plugins and matching host applications, mainly
targeted at audio processing and generation.  

There are a large number of open source and free software synthesis
packages in use or development at this time. This API ('LV2') attempts
to give programmers the ability to write simple 'plugin' audio
processors in C/C++ and link them dynamically ('plug') into a range of
these packages ('hosts').  It should be possible for any host and any
plugin to communicate completely through this interface.

LV2 is a successor to LADSPA, created to address the limitations of
LADSPA which many hosts have outgrown.

%package        devel
Summary:        API for the LV2 Audio Plugin Standard

Requires:       %{name} = %{version}-%{release}
Requires:       python3-rdflib
Requires:       python3-markdown
Provides:       lv2core-devel = 6.0
Obsoletes:      lv2core-devel < 6.0
Provides:       lv2-ui-devel = 2.4
Obsoletes:      lv2-ui-devel < 2.4

%description    devel
lv2-devel contains the lv2.h header file and headers for all of the
LV2 specification extensions and bundles.

Definitive technical documentation on LV2 plug-ins for both the host
and plug-in is contained within copious comments within the lv2.h
header file.

%package        doc
Summary:        Documentation for the LV2 Audio Plugin Standard
BuildArch:      noarch
Requires:	%{name} = %{version}-%{release}
Obsoletes:      %{name}-docs < %{version}-%{release}
Provides:       %{name}-docs = %{version}-%{release}

%description    doc
Documentation for the LV2 plugin API.

%package        example-plugins
Summary:        Examples of the LV2 Audio Plugin Standard
Requires:       %{name} = %{version}-%{release}

%description    example-plugins
Example plugins for the LV2 Audio Plugin Standard.

%prep
%autosetup -p1
# Fix wrong interpreter in lv2specgen.py
sed -i '1s|^#!.*|#!%{__python3}|' lv2specgen/lv2specgen.py

%build
%meson \
  -D docs=enabled \
  -D old_headers=true \
  -D tests=disabled

%meson_build

%install
%meson_install

# Let RPM pick docs in the files section
rm -fr %{buildroot}%{_docdir}/%{name}

%generate_compatibility_deps

%pretrans devel -p <lua>
hdir = "%{_includedir}/%{name}"
pdir = hdir .. "/lv2plug.in"

parent_dirs = {}
table.insert(parent_dirs, pdir .. "/ns/extensions")
table.insert(parent_dirs, pdir .. "/ns/ext")
table.insert(parent_dirs, pdir .. "/ns")
table.insert(parent_dirs, hdir)

for i = 1, #parent_dirs, 1 do -- not use ipairs here to guarantee order
    parent = parent_dirs[i]

    dir_entry = posix.dir(parent)
    if not(dir_entry) then
        goto skip_2
    end
    for j, path in pairs(dir_entry) do
        exclude_list = {"." , ".."}
        for k, ex in ipairs(exclude_list) do
            if path == ex then
                goto skip_1
            end
        end

        fullpath = parent .. "/"
        fullpath = fullpath .. path
        st = posix.stat(fullpath)
        if st and st.type == "link" then
            os.remove(fullpath)
        end

        ::skip_1::
    end
    ::skip_2::
end

-- Remove extra symlinks
pathlist = {}
table.insert(pathlist, "%{_inclduedir}/lv2.h")
for i = 1, #pathlist, 1 do
    fullpath = pathlist[i]
    st = posix.stat(fullpath)
    if st and st.type == "link" then
        os.remove(fullpath)
    end
end

%files
%license COPYING
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/atom.lv2
%{_libdir}/%{name}/buf-size.lv2
%{_libdir}/%{name}/core.lv2
%{_libdir}/%{name}/data-access.lv2
%{_libdir}/%{name}/dynmanifest.lv2
%{_libdir}/%{name}/event.lv2
%{_libdir}/%{name}/instance-access.lv2
%{_libdir}/%{name}/log.lv2
%{_libdir}/%{name}/midi.lv2
%{_libdir}/%{name}/morph.lv2
%{_libdir}/%{name}/options.lv2
%{_libdir}/%{name}/parameters.lv2
%{_libdir}/%{name}/patch.lv2
%{_libdir}/%{name}/port-groups.lv2
%{_libdir}/%{name}/port-props.lv2
%{_libdir}/%{name}/presets.lv2
%{_libdir}/%{name}/resize-port.lv2
%{_libdir}/%{name}/schemas.lv2
%{_libdir}/%{name}/state.lv2
%{_libdir}/%{name}/time.lv2
%{_libdir}/%{name}/ui.lv2
%{_libdir}/%{name}/units.lv2
%{_libdir}/%{name}/uri-map.lv2
%{_libdir}/%{name}/urid.lv2
%{_libdir}/%{name}/worker.lv2
%dir %{abidir}
%{abidir}/amp.dump
%{abidir}/examploscope.dump
%{abidir}/fifths.dump
%{abidir}/metro.dump

%files devel
%{_bindir}/lv2specgen.py
%{_bindir}/lv2_validate
%{_datadir}/lv2specgen
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/lv2.h

%files example-plugins
%{_libdir}/%{name}/eg-amp.lv2
%{_libdir}/%{name}/eg-fifths.lv2
%{_libdir}/%{name}/eg-metro.lv2
%{_libdir}/%{name}/eg-midigate.lv2
%{_libdir}/%{name}/eg-params.lv2
%{_libdir}/%{name}/eg-sampler.lv2
%{_libdir}/%{name}/eg-scope.lv2
%{abidir}/midigate.dump
%{abidir}/params.dump
%{abidir}/sampler.dump

%files doc
%doc %{_vpath_builddir}/doc/*
%doc NEWS README.md

%changelog
* Wed Mar 29 2023 happy_orange <songnannan@linux.alibaba.com> - 1.18.8-1
- init package
